# aquachain.py

```sudo apt-get install libssl-dev build-essential automake pkg-config libtool libffi-dev libgmp-dev```

```python3 setup.py install --user```

## Usage

```
from aquachain.aquatool import AquaTool
from aquachain.aquakeys import Keystore

```
